import { Hole, html } from "uhtml";
import { signal } from "uhtml/preactive";

type ModalContent = Hole | ((...args: any[]) => Hole);
const isModalOpen = signal(false);
const Content = signal<ModalContent | undefined>(undefined);
export const AppModal = () => html`<dialog ?open=${isModalOpen.value}>
  <article class="container-fluid">${renderContent(Content.value)}</article>
</dialog>`;

const renderContent = (innerContent: ModalContent | undefined) => {
  return typeof innerContent === "function"
    ? (innerContent as (...args: any[]) => Hole)()
    : innerContent;
};

export const openModal = (innerContent: ModalContent) => {
  Content.value = innerContent;
  isModalOpen.value = true;
};

export const closeModal = () => {
  isModalOpen.value = false;
  Content.value = undefined;
};
