import { html } from "uhtml";
import {
  deriveSharedSecret,
  decrypt,
  retrieveOrGenerateKeyPair,
} from "../utils/crypto.ts";
import { signal } from "uhtml/preactive";

const MESSAGE_OUTPUT_ID = "message";
const decryptedData = signal("");

export const ReceivePage = () => {
  return html`
    <details open>
      <summary>How To Use:</summary>
      <ul>
        <li>
          If someone used your unique request URL to generate this response URL,
          you should see the decrypted message below.
        </li>
        <li>
          Be sure to open this from the same browser you used to generate the
          original request URL.
        </li>
      </ul>
    </details>

    <form>
      <textarea
        id="${MESSAGE_OUTPUT_ID}"
        readonly
        aria-label="Decrypted Message"
        .value=${decryptedData.value}
      ></textarea>
    </form>
  `;
};

export async function decryptData({
  p,
  iv,
  m,
}: {
  p: string;
  iv: string;
  m: string;
}) {
  // Parse the 'p' parameter to get publicB
  const publicBJwk = JSON.parse(atob(p));

  // Import publicB as a CryptoKey
  const publicB = await window.crypto.subtle.importKey(
    "jwk",
    publicBJwk,
    {
      name: "ECDH",
      namedCurve: "P-256",
    },
    false,
    []
  );

  const keyPairA = await retrieveOrGenerateKeyPair();

  // Retrieve the AES key from local storage
  const aesKey = await deriveSharedSecret(keyPairA.privateKey, publicB);

  // Decrypt the message using the AES key and IV
  decryptedData.value = await decrypt(aesKey, iv, m);
}
